==> amity-sdk-6.46.0--sources.jar: main/com/amity/socialcloud/sdk/social/data/community/CommunityModelMapper.kt <==
package com.amity.socialcloud.sdk.social.data.community

import com.amity.socialcloud.sdk.common.ModelMapper
import com.amity.socialcloud.sdk.model.social.community.AmityCommunity
import com.ekoapp.ekosdk.internal.entity.CommunityEntity

internal class CommunityModelMapper : ModelMapper<CommunityEntity, AmityCommunity>() {

    override fun map(entity: CommunityEntity): AmityCommunity {
        return entity.run {
            AmityCommunity(
                communityId = communityId,
                channelId = channelId ?: "",
                userId = userId ?: "",
                displayName = displayName ?: "",
                description = description ?: "",
                avatarFileId = avatarFileId ?: "",
                isOfficial = isOfficial ?: false,
                isPublic = isPublic ?: false,
                onlyAdminCanPost = onlyAdminCanPost ?: false,
                allowCommentInStory = allowCommentInStory ?: false,
                tags = getTags(),
                metadata = metadata,
                postsCount = postsCount ?: 0,
                membersCount = membersCount ?: 0,
                isJoined = isJoined ?: false,
                isDeleted = isDeleted ?: false,
                categoryIds = categoryIds,
                categories = emptyList(),
                user = null,
                avatarImage = null,
                isPostReviewEnabled = needApprovalOnPostCreation ?: false,
                createdAt = createdAt,
                updatedAt = updatedAt,
                path = path
            )
        }
    }
}

==> amity-sdk-7.8.1-sources.jar: main/com/amity/socialcloud/sdk/social/data/community/CommunityModelMapper.kt <==
package com.amity.socialcloud.sdk.social.data.community

import com.amity.socialcloud.sdk.common.ModelMapper
import com.amity.socialcloud.sdk.model.social.community.AmityCommunity
import com.ekoapp.ekosdk.internal.entity.CommunityEntity

internal class CommunityModelMapper : ModelMapper<CommunityEntity, AmityCommunity>() {

    override fun map(entity: CommunityEntity): AmityCommunity {
        return entity.run {
            AmityCommunity(
                communityId = communityId,
                channelId = channelId ?: "",
                userId = userId ?: "",
                displayName = displayName ?: "",
                description = description ?: "",
                avatarFileId = avatarFileId ?: "",
                isOfficial = isOfficial ?: false,
                isPublic = isPublic ?: false,
                onlyAdminCanPost = onlyAdminCanPost ?: false,
                allowCommentInStory = allowCommentInStory ?: false,
                tags = getTags(),
                metadata = metadata,
                postsCount = postsCount ?: 0,
                membersCount = membersCount ?: 0,
                isJoined = isJoined ?: false,
                isDeleted = isDeleted ?: false,
                categoryIds = categoryIds,
                categories = emptyList(),
                user = null,
                avatarImage = null,
                isPostReviewEnabled = needApprovalOnPostCreation ?: false,
                createdAt = createdAt,
                updatedAt = updatedAt,
                path = path,
                isDiscoverable = isDiscoverable ?: false,
                requiresJoinApproval = requiresJoinApproval ?: false,
            )
        }
    }
}
